//
// Copyright (c) 2016, MindFusion LLC - Bulgaria.
//

using System;
using System.Drawing;
using System.Drawing.Drawing2D;


namespace MindFusion.Reporting.WinForms.Samples.CS.CustomDrawing
{
	partial class CustomDrawnReport : Report
	{
		public CustomDrawnReport()
		{
			InitializeComponent();

			sales_by_CategoryTableAdapter1.Fill(nwindDataSet1.Sales_by_Category);
			categoriesTableAdapter1.Fill(nwindDataSet1.Categories);
		}

		private void canvas_RenderContents(object sender, DrawCanvasEventArgs e)
		{
			// Calculate the sum of all sales
			if (sumSales == null)
				sumSales = sumSalesTableAdapter1.SumSalesQuery();

			if (sumSales != null)
			{
				// Calculate the current sale amount as a percent of the total sales
				double percent = (double)(decimal)e.DataValue / (double)sumSales.Value * 100;

				RectangleF bounds = e.Bounds;
				bounds.Inflate(-1, -1);

				// Draw a semi-filled rectangle illustrating the sale percantage
				double fill = bounds.Width * percent / 100;
				using (var fillBrush = new SolidBrush(Color.FromArgb(0xFF, 0x80, 0x00)))
					e.Graphics.FillRectangle(fillBrush, bounds.X, bounds.Y, (float)fill, bounds.Height);

				StringFormat format = new StringFormat();
				format.Alignment = StringAlignment.Far;
				format.LineAlignment = StringAlignment.Center;
				string text = string.Format("{0:0.##} %", percent);
				using (var font = new Font(FontName, FontSize, FontStyle))
					e.Graphics.DrawString(text, font, Brushes.Black, bounds, format);
				format.Dispose();
			}
			else
			{
			}

			using (var borderPen = new Pen(Color.FromArgb(0xD2, 0xD7, 0xE3), 0))
				e.Graphics.DrawRectangle(borderPen, e.Bounds);
		}

		private Nullable<decimal> sumSales;
	}
}
